@@ -100,7 +100,7 @@ atk_role_get_type (void)
       { ATK_ROLE_RULER, "ATK_ROLE_RULER", "ruler" },
       { ATK_ROLE_APPLICATION, "ATK_ROLE_APPLICATION", "application" },
       { ATK_ROLE_AUTOCOMPLETE, "ATK_ROLE_AUTOCOMPLETE", "autocomplete" },
-      { ATK_ROLE_EDITBAR, "ATK_ROLE_EDITBAR", "editbar" },
+      { ATK_ROLE_EDITBAR, "ATK_ROLE_EDITBAR", "edit-bar" },
       { ATK_ROLE_EMBEDDED, "ATK_ROLE_EMBEDDED", "embedded" },
       { ATK_ROLE_ENTRY, "ATK_ROLE_ENTRY", "entry" },
       { ATK_ROLE_CHART, "ATK_ROLE_CHART", "chart" },
