@@ -101,6 +101,13 @@ atk_no_op_object_get_type (void)
         NULL
     };
 
+    static const GInterfaceInfo atk_table_cell_info =
+    {
+        (GInterfaceInitFunc) NULL,
+        (GInterfaceFinalizeFunc) NULL,
+        NULL
+    };
+
     static const GInterfaceInfo atk_text_info =
     {
         (GInterfaceInitFunc) NULL,
@@ -150,6 +157,8 @@ atk_no_op_object_get_type (void)
                                  &atk_selection_info);
     g_type_add_interface_static (type, ATK_TYPE_TABLE,
                                  &atk_table_info);
+    g_type_add_interface_static (type, ATK_TYPE_TABLE_CELL,
+                                 &atk_table_cell_info);
     g_type_add_interface_static (type, ATK_TYPE_TEXT,
                                  &atk_text_info);
     g_type_add_interface_static (type, ATK_TYPE_HYPERTEXT,
